:orphan:

========
Unlisted
========

This document is here to trigger documentation generation for internal
functions and classes which should not be on the index page,
but should still have a generated page.

.. currentmodule:: skrub

.. autosummary::
   :toctree: reference/generated/
   :template: base.rst
   :nosignatures:

   datasets.DatasetAll
   datasets.DatasetInfoOnly
